==> sinosun-ui-0.0.5.tgz: package/es/range-picker/index.js <==
import RangePickerView from '../range-picker-view';
import Popup from "../popup";
import TransferDom from '../directives/transfer-dom';
import { isPC } from '../utils/commonUtil';
import { dateFormat } from '../utils/dateUtil';
import "./index.less";

var DatetimePicker = {
    name: "DateTimePicker",
    data: function data() {
        return {
            show: false,
            forceUpdate: false,
            currentValue: ''
        };
    },

    directives: { TransferDom: TransferDom },
    props: {
        value: [String, Number, Array, Date],
        readonly: Boolean,
        mode: {
            type: String,
            'default': 'date'
        },
        displayFormat: {
            type: String,
            'default': 'YYYY/MM/DD'
        }
    },
    computed: {
        formatValue: function formatValue() {
            var currentValue = this.currentValue;

            return dateFormat(new Date(currentValue[0]), 'YYYY/MM/DD') + ' - ' + dateFormat(new Date(currentValue[1]), 'YYYY/MM/DD');
        }
    },
    created: function created() {
        this.currentValue = this.value || new Date();
    },
    mounted: function mounted() {},

    methods: {
        onInput: function onInput(val) {
            this.show = val;
        },
        onShow: function onShow() {
            this.$emit('show');
        },
        onHide: function onHide() {
            this.show = false;
            this.$emit('hide');
            // this.currentValue = this.value;
            // setTimeout(() => {
            //     this.forceUpdate = false;
            // }, 150);
        },
        onClick: function onClick() {
            var _this = this;

            if (!this.readonly) {
                var activeTagName = window.activeTagName || '';

                if (!isPC() && activeTagName.toUpperCase() === 'INPUT' || activeTagName.toUpperCase() === 'TEXTAREA') {
                    setTimeout(function () {
                        _this.show = true;
                        _this.forceUpdate = true;
                    }, 300);
                } else {
                    this.show = true;
                    this.forceUpdate = true;
                }
            }
        },
        onChange: function onChange(val) {
            var _this2 = this;

            console.log('range-picker  onChange == ', val);
            if (!this.$listeners['change']) {
                this.$emit('input', val);
            }

            this.show = false;
            setTimeout(function () {
                _this2.forceUpdate = false;
            }, 150);
            this.$emit('change', val);
        }
    },
    watch: {
        value: function value(newVal, oldVal) {
            this.currentValue = newVal;
        }
    },
    render: function render() {
        var h = arguments[0];
        var currentValue = this.currentValue,
            formatValue = this.formatValue,
            forceUpdate = this.forceUpdate,
            show = this.show;


        return h(
            'div',
            { 'class': 'sn-range-picker', on: {
                    'click': this.onClick
                }
            },
            [h(
                'span',
                { 'class': 'sn-range-picker-value' },
                [formatValue]
            ), h(
                'div',
                {
                    directives: [{
                        name: 'transfer-dom',
                        value: true
                    }]
                },
                [h(
                    Popup,
                    {
                        attrs: { value: show },
                        on: {
                            'input': this.onInput,
                            'click-overlay': this.onHide
                        }
                    },
                    [forceUpdate ? h(RangePickerView, {
                        attrs: {
                            value: currentValue
                        },
                        on: {
                            'change': this.onChange
                        }
                    }) : null]
                )]
            )]
        );
    }
};

export default DatetimePicker;

==> sinosun-ui-0.1.4.tgz: package/es/range-picker/index.js <==
import RangePickerView from '../range-picker-view';
import Popup from "../popup";
import TransferDom from '../directives/transfer-dom';
import { isPC } from '../utils/commonUtil';
import { dateFormat } from '../utils/dateUtil';
import "./index.less";

var DatetimePicker = {
    name: "DateTimePicker",
    data: function data() {
        return {
            show: false,
            forceUpdate: false,
            currentValue: ''
        };
    },

    directives: { TransferDom: TransferDom },
    props: {
        value: [String, Number, Array, Date],
        readonly: Boolean,
        mode: {
            type: String,
            'default': 'date'
        },
        displayFormat: {
            type: String,
            'default': 'YYYY/MM/DD'
        }
    },
    computed: {
        formatValue: function formatValue() {
            var currentValue = this.currentValue;

            return dateFormat(new Date(currentValue[0]), 'YYYY/MM/DD') + ' - ' + dateFormat(new Date(currentValue[1]), 'YYYY/MM/DD');
        }
    },
    created: function created() {
        this.currentValue = this.value || new Date();
    },
    mounted: function mounted() {},

    methods: {
        onInput: function onInput(val) {
            this.show = val;
        },
        onShow: function onShow() {
            this.$emit('show');
        },
        onHide: function onHide() {
            this.show = false;
            this.$emit('hide');
            // this.currentValue = this.value;
            // setTimeout(() => {
            //     this.forceUpdate = false;
            // }, 150);
        },
        onClick: function onClick() {
            var _this = this;

            if (!this.readonly) {
                var activeTagName = window.activeTagName || '';

                if (!isPC() && activeTagName.toUpperCase() === 'INPUT' || activeTagName.toUpperCase() === 'TEXTAREA') {
                    setTimeout(function () {
                        _this.show = true;
                        _this.forceUpdate = true;
                    }, 300);
                } else {
                    this.show = true;
                    this.forceUpdate = true;
                }
            }
        },
        onChange: function onChange(val) {
            var _this2 = this;

            console.log('range-picker  onChange == ', val);
            if (!this.$listeners['change']) {
                this.$emit('input', val);
            }

            this.show = false;
            setTimeout(function () {
                _this2.forceUpdate = false;
            }, 150);
            this.$emit('change', val);
        }
    },
    watch: {
        value: function value(newVal, oldVal) {
            this.currentValue = newVal;
        }
    },
    render: function render() {
        var h = arguments[0];
        var currentValue = this.currentValue,
            formatValue = this.formatValue,
            forceUpdate = this.forceUpdate,
            show = this.show;


        return h(
            'div',
            { 'class': 'sn-range-picker', on: {
                    'click': this.onClick
                }
            },
            [h(
                'span',
                { 'class': 'sn-range-picker-value' },
                [formatValue]
            ), h(
                'div',
                {
                    directives: [{
                        name: 'transfer-dom',
                        value: true
                    }]
                },
                [h(
                    Popup,
                    {
                        attrs: { value: show },
                        on: {
                            'input': this.onInput,
                            'click-overlay': this.onHide
                        },
                        style: 'background: transparent;' },
                    [forceUpdate ? h(
                        'div',
                        { 'class': 'sn-range-picker-content' },
                        [h(RangePickerView, {
                            attrs: {
                                value: currentValue
                            },
                            on: {
                                'change': this.onChange
                            }
                        })]
                    ) : null]
                )]
            )]
        );
    }
};

export default DatetimePicker;
